BlocRelatedClassNamingConfig class
Configuration for the bloc_related_class_naming rule.
Each suffix is appended to the BLoC/Cubit subject name (the part before
Bloc or Cubit) to form the expected class name.
For example, for FooBloc the default expected names are:
- state →
FooState - event →
FooEvent - presentation event →
FooPresentationEvent
Constructors
- BlocRelatedClassNamingConfig({String stateSuffix = 'State', String eventSuffix = 'Event', String presentationEventSuffix = 'PresentationEvent'})
-
const
Properties
- eventSuffix → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- presentationEventSuffix → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stateSuffix → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited