LeanCodeLintPlugin class final
Analyzer plugin implementation for leancode_lint.
Consumers that want to configure the lints programmatically should import
package:leancode_lint/plugin.dart and instantiate LeanCodeLintPlugin
from their own plugin package.
- Inheritance
-
- Object
- Plugin
- LeanCodeLintPlugin
Constructors
- LeanCodeLintPlugin({String name = 'leancode_lint', LeanCodeLintConfig config = const .new()})
Properties
- config → LeanCodeLintConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
A user-visible name for this plugin, used for error-reporting and
insights-reporting purposes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
register(
PluginRegistry registry) → void -
Registers analysis rules, quick fixes, and assists.
override
-
shutDown(
) → FutureOr< void> -
inherited
-
start(
) → FutureOr< void> -
Initializes any necessary start-up state that is required for this plugin
to run.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited